@@ -1,5 +1,6 @@
 """Module containing the CLI programs for histoprint."""
 
+import contextlib
 from io import StringIO
 from typing import Any, Dict, List, Tuple
 
@@ -7,7 +8,7 @@ import click
 import numpy as np
 
 import histoprint as hp
-import histoprint.formatter as formatter
+from histoprint import formatter
 
 
 @click.command()
@@ -43,22 +44,19 @@ import histoprint.formatter as formatter
     "--symbols",
     type=str,
     default=formatter.DEFAULT_SYMBOLS,
-    help="Symbol cycle for multiple histograms. Choices & default: '%s'"
-    % (formatter.DEFAULT_SYMBOLS,),
+    help=f"Symbol cycle for multiple histograms. Choices & default: '{formatter.DEFAULT_SYMBOLS}'",
 )
 @click.option(
     "--fg-colors",
     type=str,
     default=formatter.DEFAULT_FG_COLORS,
-    help="Colour cycle for foreground colours. Default: '%s', Choices: '0rgbcmykwRGBCMYKW'"
-    % (formatter.DEFAULT_FG_COLORS,),
+    help=f"Colour cycle for foreground colours. Default: '{formatter.DEFAULT_FG_COLORS}', Choices: '0rgbcmykwRGBCMYKW'",
 )
 @click.option(
     "--bg-colors",
     type=str,
     default=formatter.DEFAULT_BG_COLORS,
-    help="Colour cycle for background colours. Default: '%s', Choices: '0rgbcmykwRGBCMYKW'"
-    % (formatter.DEFAULT_BG_COLORS,),
+    help=f"Colour cycle for background colours. Default: '{formatter.DEFAULT_BG_COLORS}', Choices: '0rgbcmykwRGBCMYKW'",
 )
 @click.option(
     "-f",
@@ -126,7 +124,7 @@ def histoprint(infile, **kwargs):
         try:
             data_handle.seek(0)
             _histoprint_txt(data_handle, **kwargs)
-            exit(0)
+            return
         except ValueError:
             pass
 
@@ -134,19 +132,18 @@ def histoprint(infile, **kwargs):
         try:
             data_handle.seek(0)
             _histoprint_csv(data_handle, **kwargs)
-            exit(0)
+            raise SystemExit(0)
         except ImportError:
             click.echo("Cannot try CSV file format. Pandas module not found.", err=True)
 
     # Try to interpret file as ROOT file
     try:
         _histoprint_root(infile, **kwargs)
-        exit(0)
+        return
     except ImportError:
         pass
 
-    click.echo("Could not interpret file format.", err=True)
-    exit(1)
+    raise click.FileError(infile, "Could not interpret the file format")
 
 
 def _bin_edges(kwargs, data):
@@ -182,7 +179,7 @@ def _histoprint_txt(infile, **kwargs):
         except Exception as e:
             click.echo("Error interpreting the cut string:", err=True)
             click.echo(e, err=True)
-            exit(1)
+            raise SystemExit(1) from None
 
     # Interpret field numbers
     fields = kwargs.pop("fields", [])
@@ -191,18 +188,18 @@ def _histoprint_txt(infile, **kwargs):
             fields = [int(f) for f in fields]
         except ValueError:
             click.echo("Fields for a TXT file must be integers.", err=True)
-            exit(1)
+            raise SystemExit(1) from None
         try:
             data = data[fields]
         except KeyError:
             click.echo("Field out of bounds.", err=True)
-            exit(1)
+            raise SystemExit(1) from None
 
     # Interpret bins
     bins = _bin_edges(kwargs, data)
 
     # Create the histogram(s)
-    hist = ([], bins)  # type: Tuple[Any, Any]
+    hist: Tuple[Any, Any] = ([], bins)
     for d in data:
         hist[0].append(np.histogram(d, bins=bins)[0])
 
@@ -224,7 +221,7 @@ def _histoprint_csv(infile, **kwargs):
         except Exception as e:
             click.echo("Error interpreting the cut string:", err=True)
             click.echo(e, err=True)
-            exit(1)
+            raise SystemExit(1) from None
 
     # Interpret field numbers/names
     fields = list(kwargs.pop("fields", []))
@@ -233,7 +230,7 @@ def _histoprint_csv(infile, **kwargs):
             data = data[fields]
         except KeyError:
             click.echo("Unknown column name.", err=True)
-            exit(1)
+            raise SystemExit(1) from None
 
     # Get default columns labels
     if kwargs.get("labels", ("",)) == ("",):
@@ -246,7 +243,7 @@ def _histoprint_csv(infile, **kwargs):
     bins = _bin_edges(kwargs, data)
 
     # Create the histogram(s)
-    hist = ([], bins)  # type: Tuple[Any, Any]
+    hist: Tuple[Any, Any] = ([], bins)
     for d in data:
         hist[0].append(np.histogram(d, bins=bins)[0])
 
@@ -278,7 +275,7 @@ def _histoprint_root(infile, **kwargs):
     if len(fields) == 0:
         click.echo("Must specify at least one field for ROOT files.", err=True)
         click.echo(F.keys(), err=True)
-        exit(1)
+        raise SystemExit(1)
 
     # Get default columns labels
     if kwargs.get("labels", ("",)) == ("",):
@@ -306,8 +303,8 @@ def _histoprint_root(infile, **kwargs):
 
     data = []
     # Find TTrees
-    trees = []  # type: List[up.models.TTree.Model_TTree_v19]
-    tree_fields = []  # type: List[List[Dict[str, Any]]]
+    trees: List[up.models.TTree.Model_TTree_v19] = []
+    tree_fields: List[List[Dict[str, Any]]] = []
     for field, label in zip(fields, labels):
         branch = F
         splitfield = field.split("/")
@@ -316,17 +313,12 @@ def _histoprint_root(infile, **kwargs):
                 branch = branch[key]
             except KeyError:
                 click.echo(
-                    "Could not find key '%s'. Possible values: %s"
-                    % (key, branch.keys()),
+                    f"Could not find key '{key}'. Possible values: {branch.keys()}",
                     err=True,
                 )
-                exit(1)
+                raise SystemExit(1) from None
             # Has `arrays` method?
-            try:
-                branch.arrays
-            except AttributeError:
-                pass
-            else:
+            if hasattr(branch, "arrays"):
                 # Found it
                 path = "/".join(splitfield[i + 1 :])
                 if branch in trees:
@@ -349,18 +341,15 @@ def _histoprint_root(infile, **kwargs):
             labels.append(field["label"])
             split = field["path"].split("[")
             path = split[0]
-            if len(split) > 1:
-                slic = "[" + "[".join(split[1:])
-            else:
-                slic = ""
+            slic = "[" + "[".join(split[1:]) if len(split) > 1 else ""
             aliases[field["label"]] = path
             # Get the branches
             try:
                 d.append(eval("tree[path].array()" + slic))
             except up.KeyInFileError as e:
                 click.echo(e, err=True)
-                click.echo("Possible keys: %s" % tree.keys(), err=True)
-                exit(1)
+                click.echo(f"Possible keys: {tree.keys()}", err=True)
+                raise SystemExit(1) from None
 
         # Cut on values
         if cut is not None:
@@ -368,22 +357,20 @@ def _histoprint_root(infile, **kwargs):
                 index = tree.arrays("cut", aliases={"cut": cut}).cut
             except up.KeyInFileError as e:
                 click.echo(e, err=True)
-                click.echo("Possible keys: %s" % tree.keys(), err=True)
-                exit(1)
+                click.echo(f"Possible keys: {tree.keys()}", err=True)
+                raise SystemExit(1) from None
             except Exception as e:
                 click.echo("Error interpreting the cut string:", err=True)
                 click.echo(e, err=True)
-                exit(1)
+                raise SystemExit(1) from None
 
             for i in range(len(d)):
                 d[i] = d[i][index]
 
         # Flatten if necessary
         for i in range(len(d)):
-            try:
+            with contextlib.suppress(ValueError):
                 d[i] = ak.flatten(d[i])
-            except ValueError:
-                pass
 
             # Turn into flat numpy array
             d[i] = ak.to_numpy(d[i])
